powered by
Interactive data exploration with one line of code, automated reporting or use an easy to remember set of tidy functions for low code exploratory data analysis.
Maintainer: Roland Krasser [email protected]
Useful links:
https://rolkra.github.io/explore/
https://github.com/rolkra/explore
Report bugs at https://github.com/rolkra/explore/issues